function [out] = HimmelblauNLO(R)
% Himmelblau non-linear optimization (5-D) benchmark function, a part of
% "CFOTool: a MATLAB toolbox for Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------
%
% MAXIMUM ~ 31025.5562644972 @ (78.0,33.0,27.0709971052,45.0,44.9692425501)
%
% Reference: "Constrained Optimization using CODEQ," Mahamed G.H. Omran & Ayed Salman,
% Chaos, Solitons and Tractals, 42(2009), 662-668
% -------------------------------------------------------------------------

Z = +Inf;

x1 = R(:, 1);
x2 = R(:, 2);
x3 = R(:, 3);
x4 = R(:, 4);
x5 = R(:, 5);

g1 = 85.334407 + 0.0056858 .* x2 .* x5 + 0.00026 .* x1 .* x4 - 0.0022053 .* x3 .* x5;

g2 = 80.51249 + 0.0071317 .* x2 .* x5 + 0.0029955 .* x1 .* x2 + 0.0021813 .* x3 .* x3;

g3 = 9.300961 + 0.0047026 .* x3 .* x5 + 0.0012547 .* x1 .* x3 + 0.0019085 .* x3 .* x4;

if ~(g1 < 0 || g1 > 92 || g2 < 90 || g2 > 110 || g3 < 20 || g3 > 25)
    Z = 5.3578547 .* x3 .* x3 + 0.8356891 .* x1 .* x5 + 37.29329 .* x1 - 40792.141;
end

out = -Z;
end

