function [out] = ParrottF4(R)
% Parrott F4 (1-D) benchmark function, a part of "CFOTool: a MATLAB toolbox
% for Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------
%
% MAXIMUM = 1 AT ~0.0796875... WITH ZERO OFFSET (SEEMS TO WORK BEST WITH JUST 3 PROBES, BUT NOT ALLOWED IN THIS VERSION...)
%
% References:
%
% Beasley, D., D. R. Bull, and R. R. Martin, "A Sequential Niche Technique for Multimodal
% Function Optimization," Evol. Comp. (MIT Press), vol. 1, no. 2, 1993, pp. 101-125
% (online at http://citeseer.ist.psu.edu/beasley93sequential.html).
%
% Parrott, D., and X. Li, Locating and Tracking Multiple Dynamic Optima by a Particle Swarm
% Model Using Speciation, IEEE Trans. Evol. Computation, vol. 10, no. 4, Aug. 2006, pp. 440-458.
% -------------------------------------------------------------------------

offset = 0;

x = R(:, 1);

out = exp(-2 .* log(2) .* ((x - 0.08 - offset) ./ 0.854) .^ 2) *...
    (sin(5 .* pi .* ((x - offset) .^ 0.75 - 0.05))) .^ 6; % WARNING! This is a NATURAL LOG, NOT Log10!!!

end

