function [Nd, Np, XiMin, XiMax, DiagLength] = GetFunctionRunParameters(FunctionName)
% GetFunctionRunParameters function, a part of "CFOTool: a MATLAB toolbox
% for Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------

switch FunctionName
    case 'ParrottF4'
        Nd = 1;
        Np = 3;
        
        XiMin = 0;
        XiMax = 1;
        
    case 'SGO'
        
        Nd = 2;
        Np = 8;
        
        XiMin = -50 .* ones(1, Nd);
        XiMax = 50 .* ones(1, Nd);
        
    case 'GP'
        
        Nd = 2;
        Np = 8;
        
        XiMin = -100 .* ones(1, Nd);
        XiMax = 100 .* ones(1, Nd);
                
    case 'StepFunction'
        
        Nd = 2;
        Np = 8;
        
        XiMin = -100 .* ones(1, Nd);
        XiMax = 100 .* ones(1, Nd);
        
        % XiMin = [72, 27];
        % XiMax(1) = [78, 33];
        % use this to plot STEP detail
        
    case 'Schwefel226'
        
        Nd = 30;
        Np = 120;
        
        XiMin = -500 .* ones(1, Nd);
        XiMax = 500 .* ones(1, Nd);
        
    case 'Colville'
        
        Nd = 4;
        Np = 16;
        
        XiMin = -10 .* ones(1, Nd);
        XiMax = 10 .* ones(1, Nd);
        
    case 'Griewank'
        
        Nd = 2;
        Np = 8;
        
        XiMin = -600 .* ones(1, Nd);
        XiMax = 600 .* ones(1, Nd);
        
    case 'Himmelblau'
        
        Nd = 2;
        Np = 8;
        
        XiMin = -6 .* ones(1, Nd);
        XiMax = 6 .* ones(1, Nd);
        
    case 'Rosenbrock' % (n-D)
        
        Nd = 2;
        Np = 8;
        
        XiMin = -2 .* ones(1, Nd);
        XiMax = 2 .* ones(1, Nd);
        
        % XiMin = -6 .* ones(1, Nd);
        % XiMax = 6 .* ones(1, Nd);
        
    case 'Spherefcn' % (n-D)
        
        Nd = 2;
        Np = 8;
        
        XiMin = -100 .* ones(1, Nd);
        XiMax = 100 .* ones(1, Nd);
        
    case 'HimmelblauNLO' % (5-D)
        
        Nd = 5;
        Np = 20;
        
        XiMin = [78, 33, 27, 27, 27];
        XiMax = [102, 45, 45, 45, 45];
        
    case 'Tripod' % (2-D)
        
        Nd = 2;
        Np = 8;
        
        XiMin = -100 .* ones(1, Nd);
        XiMax = 100 .* ones(1, Nd);
        
    case 'RosenbrockF6' % (10-D)
        
        Nd = 10;
        Np = 40;
        
        
        XiMin = -100 .* ones(1, Nd);
        XiMax = 100 .* ones(1, Nd);
        
    case 'CompressionSpring' % (3-D)
        
        Nd = 3;
        Np = 12;
        
        XiMin = [1, 0.6, 0.207];
        XiMax = [70, 3, 0.5];
        
    case 'GearTrain' % (4-D)
        
        Nd = 4;
        Np = 16;
        
        XiMin = 12 .* ones(1, Nd);
        XiMax = 60 .* ones(1, Nd);
        
    case 'F1' % (n-D)
        
        Nd = 30;
        Np = 60;
        
        XiMin = -100 .* ones(1, Nd);
        XiMax = 100 .* ones(1, Nd);
        
    case 'F2' % (n-D)
        
        Nd = 30;
        Np = 60;
        
        XiMin = -10 .* ones(1, Nd);
        XiMax = 10 .* ones(1, Nd);
        
    case 'F3' % (n-D)
        
        Nd = 30;
        Np = 60;
        
        XiMin = -100 .* ones(1, Nd);
        XiMax = 100 .* ones(1, Nd);
        
    case 'F4' % (n-D)
        
        Nd = 30;
        Np = 60;
        
        XiMin = -100 .* ones(1, Nd);
        XiMax = 100 .* ones(1, Nd);
        
    case 'F5' % (n-D)
        
        Nd = 30;
        Np = 60;
        
        XiMin = -30 .* ones(1, Nd);
        XiMax = 30 .* ones(1, Nd);
        
    case 'F6' % (n-D) STEP
        
        Nd = 30;
        Np = 60;
        
        XiMin = -100 .* ones(1, Nd);
        XiMax = 100 .* ones(1, Nd);
        
    case 'F7' % (n-D)
        
        Nd = 30;
        Np = 60;
        
        XiMin = -1.28 .* ones(1, Nd);
        XiMax = 1.28 .* ones(1, Nd);
        
    case 'F8' % (n-D)
        
        Nd = 30;
        Np = 60;
        
        XiMin = -500 .* ones(1, Nd);
        XiMax = 500 .* ones(1, Nd);
        
    case 'F9' % (n-D)
        
        Nd = 30;
        Np = 60;
        
        XiMin = -5.12 .* ones(1, Nd);
        XiMax = 5.12 .* ones(1, Nd);
        
    case 'F10' % (n-D) Ackley's Function
        
        Nd = 30;
        Np = 60;
        
        XiMin = -32 .* ones(1, Nd);
        XiMax = 32 .* ones(1, Nd);
        
    case 'F11' % (n-D)
        
        Nd = 30;
        Np = 60;
        
        XiMin = -600 .* ones(1, Nd);
        XiMax = 600 .* ones(1, Nd);
        
    case 'F12' % (n-D) Penalized #1
        
        Nd = 30;
        Np = 60;
        
        XiMin = -50 .* ones(1, Nd);
        XiMax = 50 .* ones(1, Nd);
        % XiMin = -5 .* ones(1, Nd);
        % XiMax = 5 .* ones(1, Nd);
        % use this interval for second run to improve performance
        
    case 'F13' % (n-D) Penalized #2
        
        Nd = 30;
        Np = 60;
        
        XiMin = -50 .* ones(1, Nd);
        XiMax = 50 .* ones(1, Nd);
        
    case 'F14' % (2-D) Shekel's Foxholes
        
        Nd = 2;
        Np = 8;
        
        XiMin = -65.536 .* ones(1, Nd);
        XiMax = 65.536 .* ones(1, Nd);
        
    case 'F15' % (4-D) Kowalik's Function
        
        Nd = 4;
        Np = 16;
        
        XiMin = -5 .* ones(1, Nd);
        XiMax = 5 .* ones(1, Nd);
        
    case 'F16' % (2-D) Camel Back
        
        Nd = 2;
        Np = 8;
        
        XiMin = -5 .* ones(1, Nd);
        XiMax = 5 .* ones(1, Nd);
        
    case 'F17' % (2-D) Branin
        
        Nd = 2;
        Np = 8;
        
        XiMin = [-5 0];
        XiMax = [10 15];
        
    case 'F18' % (2-D) Goldstein-Price
        
        Nd = 2;
        Np = 8;
        
        XiMin = -2 .* ones(1, Nd);
        XiMax = 2 .* ones(1, Nd);
        
    case 'F19' % (3-D) Hartman's Family #1
        
        Nd = 3;
        Np = 12;
        
        XiMin = zeros(1, Nd);
        XiMax = ones(1, Nd);
        
    case 'F20' % (6-D) Hartman's Family #2
        
        Nd = 6;
        Np = 24;
        
        XiMin = zeros(1, Nd);
        XiMax = ones(1, Nd);
        
    case 'F21' % (4-D) Shekel's Family m=5
        
        Nd = 4;
        Np = 16;
        
        XiMin = zeros(1, Nd);
        XiMax = 10 .* ones(1, Nd);
        
    case 'F22' % (4-D) Shekel's Family m=7
        
        Nd = 4;
        Np = 16;
        
        XiMin = zeros(1, Nd);
        XiMax = 10 .* ones(1, Nd);
        
    case 'F23' % (4-D) Shekel's Family m=10
        
        Nd = 4;
        Np = 16;
        
        XiMin = zeros(1, Nd);
        XiMax = 10 .* ones(1, Nd);
        
        % ======================================================================================
        % NOTE - DON'T FORGET TO ADD NEW TEST FUNCTIONS TO FUNCTION ObjectiveFunction() ABOVE !!
        % ======================================================================================
        
end

% if Nd > 100
%     Nt = min(Nt, 200); % to avoid array dimensioning problems
% end

DiagLength = sqrt(sum((XiMax - XiMin) .^ 2, 2)); % compute length of decision space principal diagonal
end

