function [out] = SGO(R)
% SGO  benchmark function 2-D, a part of "CFOTool: a MATLAB toolbox for
% Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------
% Evaluates SGO function on input probe matrix
%
% MAXIMUM = ~130.8323226... @ ~(-2.8362075...,-2.8362075...) WITH ZERO OFFSET.
%
% Reference:
% Hsiao, Y., Chuang, C., Jiang, J., and Chien, C., "A Novel Optimization
% Algorithm: Space Gravitational Optimization," Proc. of 2005 IEEE
% International Conference on Systems, Man, and Cybernetics, 3, 2323-2328. (2005)
%
% Input:
% R: Probes matrix
%
% Outputs:
% out: SGO(R)
%
% -------------------------------------------------------------------------

SGOx1offset = 0;
SGOx2offset = 0;

x1 = R(:, 1) - SGOx1offset;
x2 = R(:, 2) - SGOx2offset;
t1 = x1 .^ 4 - 16 .* x1 .^ 2 + 0.5 .* x1;
t2 = x2 .^ 4 - 16 .* x2 .^ 2 + 0.5 .* x2;

out = -(t1 + t2);

end

