% Test program for CFO functions, a part of "CFOTool: a MATLAB toolbox for
% Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------

clear all;

% --------------------- Initial Parameter Values --------------------------

NumGammas = 3; % 11 % default value for functions other than BOWTIE

% CFO EXPONENTS Alpha & Beta
Alpha = 1;
Beta = 1;

Nt = 1000; % set to a large value expecting early termination
FrepInit  = 0.5; % Initial Reposition Factor
DeltaFrep = 0.1; % Delta Reposition Factor
MinFrep   = 0.05; % Minimum Reposition Factor
FunctionName = 'SGO'; % Name of the objective function

% Decision space boundaries
[Nd, Np, XiMin, XiMax, DiagLength] = GetFunctionRunParameters(FunctionName);

% -----------------------Main function evaluation -------------------------
% times = 0;
% for i = 1:100
% display(i);
tic;
[BestFitnessOverall, BestProbeNumberOveral, BestTimeStepOveral, ...
    BestNpNd, BestGamma, LastStepBestRun, Rbest, Mbest, Neval] = ...
    ParameterFreeCFO(FunctionName, Nd, Nt, XiMin, XiMax, NumGammas, ...
    Alpha, Beta, FrepInit, DeltaFrep, MinFrep);
display(sprintf('Total run time: %d seconds', toc));
% times = times + toc;
% end
% display(times / 100);
