function [out] = Colville(R)
% Colville  benchmark function (4-D), a part of "CFOTool: a MATLAB toolbox
% for Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------
%
% MAXIMUM = 0 @ (1,1,1,1) WITH ZERO OFFSET.
%
% Reference:
%
% Doo-Hyun, and Se-Young, O., "A New Mutation Rule for Evolutionary Programming Motivated from
% Backpropagation Learning," IEEE Trans. Evolutionary Computation, Vol. 4, No. 2, pp. 188-190,
% July 2000.
% -------------------------------------------------------------------------

offset = 0; % 7.123

x1 = R(:, 1) - offset;
x2 = R(: ,2) - offset;
x3 = R(:, 3) - offset;
x4 = R(:, 4) - offset;

Z =  100 .* (x2 - x1 .^ 2) .^ 2 + (1 - x1) .^ 2 + ...
    90 .* (x4 - x3 .^ 2) .^ 2 + (1 - x3) .^ 2 + ...
    10.1 .* ((x2 - 1) .^ 2 + (x4 - 1) .^ 2) + ...
    19.8 .* (x2 - 1) .* (x4 - 1);

out = -Z;
end

