function [out] = CompressionSpring(R)
% Compression Spring (3-D) benchmark function, a part of "CFOTool: a MATLAB
% toolbox for Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------
%
% MAXIMUM = 394 at (0,-50)
%
% Reference: "Appendix: A mini-benchmark," Maurice Clerc (NOTE: Uses his notation...)
% -------------------------------------------------------------------------

Z = +Inf;

x1 = round(R(:, 1)); % Note: Round function in MATLAB is different from
                     % ROUND function in PowerBasic as in MATLAB it
                     % rounds the X.5 to (X + 1) while PowerBasic
                     % rounds it to the nearest even number.
x2 = R(:, 2);
x3 = round(R(:, 3) .* 1000) ./ 1000;

Cf = 1 + 0.75 .* x3 ./ (x2 - x3) + 0.615 .* x3 ./ x2;

Fmax = 1000;
S = 189000;
Lmax = 14;
SigPM = 6;
Fp = 300;
SigW = 1.25;
K = 11.5E6 .* x3 .^ 4 ./ (8 .* x1 .* x2 .^ 3);
Lf = Fmax ./ K + 1.05 .* (x1 + 2) .* x3;
SigP = Fp ./ K;

g1 = 8 .* Cf .* Fmax .* x2 ./ (pi .* x3 .^ 3) - S;
g2 = Lf - Lmax;
g3 = SigP - SigPM;
g4 = SigP - Fp ./ K; % WARNING!  03-19-10.  THIS IS SATISFIED EXACTLY (SEE CLERC's EMAIL - TYPO IN HIS BENCHMARKS)
g5 = SigW - (Fmax - Fp) ./ K;

if ~(g1 > 0 || g2 > 0 || g3 > 0 || g4 > 0 || g5 > 0)
    Z = pi .^ 2 .* x2 .* x3 .^ 2 .* (x1 + 1) ./ 4;
end

out = -Z;
end

