function [out] = StepFunction(R)
% Step  benchmark function (n-D), a part of "CFOTool: a MATLAB toolbox for
% Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------
% MAXIMUM VALUE = 0 @ [Offset]^n.
%
% Reference:
%
% Yao, X., Liu, Y., and Lin, G., "Evolutionary Programming Made Faster,"
% IEEE Trans. Evolutionary Computation, Vol. 3, No. 2, 82-102, Jul. 1999.
% -------------------------------------------------------------------------


[Np, Nd] = size(R);
Z = zeros(Np, 1);
Offset = 0;

for i = 1:Nd
    if (Nd == 2 && i == 1)
        Offset = 75;
    end
    if (Nd == 2 && i == 2)
        Offset = 35; % 30 %35
    end
    
    Z = Z + floor((R(:, i) - Offset) + 0.5) .^ 2;
end

out = -Z;
end

