function [out] = Tripod(R)
% Tripod (2-D) benchmark function, a part of "CFOTool: a MATLAB toolbox for
% Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------
%
% MAXIMUM = 0 at (0,-50)
%
% Reference: "Appendix: A mini-benchmark," Maurice Clerc
% -------------------------------------------------------------------------

x1 = R(:, 1);
x2 = R(:, 2);

s1 = Sign1(x1);
s2 = Sign1(x2);

t1 = (1 - s2) .* (abs(x1) + abs(x2 + 50));
t2 = 0.5 .* (1 + s2) .* (1 - s1) .* (1 + abs(x1 + 50) + abs(x2 - 50));
t3 = (1 + s1) .* (2 + abs(x1 - 50) + abs(x2 - 50));

Z = 0.5 .* (t1 + t2 + t3);

out = -Z;
end

