function [out] = HasFITNESSsaturated(Nsteps, MWindow, BestFitness, j)
% Has Fitness Saturated function, a part of "CFOTool: a MATLAB
% toolbox for Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------
% Determines if fitness has saturated.
% 
% Inputs:
% M: Fitness matrix
% Nsteps: Number of steps passed till executing this function
% j: Current step number
%
% Output:
% out: 1 if fitness has saturated, 0 if fitness has not saturated
%
% -------------------------------------------------------------------------

out = 0;

if j < (Nsteps + 11) % execute at least 10 steps after averaging interval before performing this check
    return;
end

FitnessSatTOL = 0.000001; % tolerance for FITNESS saturation
MeanFitness = mean(MWindow);

if abs(MeanFitness - BestFitness) <= FitnessSatTOL % saturation if (avg value - last value) are within TOL
    out = 1;
end

end

