function [R] = RetrieveErrantProbes(R, prevR, XiMin, XiMax, Frep)
% Retrieve Errant Probes function, a part of "CFOTool: a MATLAB
% toolbox for Central Force Optimization (CFO)" project
%
% Copyright (C) 2011  Hamed Abdy, Richard A. Formatto, Seyyed Hamid Zahiri
% 
% CFOTool is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CFOTool is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% MATLAB is a registered trademark of The MathWorks, Inc.
%
% For more information please see "README.txt" file that you recieved with
% this code.
% -------------------------------------------------------------------------
%
% Inputs:
% R: Probes matrix
% j: Current step number
% XiMin: Minimum value in dimensions matrix
% XiMax: Maximum value in dimensions matrix
% Frep: Reposition factor
%
% Output:
% R: Probes matrix
%
% -------------------------------------------------------------------------

Np = size(R, 1);
repXiMin = repmat(XiMin, Np, 1);
repXiMax = repmat(XiMax, Np, 1);

Rcomp = R < repXiMin;
R = ~Rcomp .* R + Rcomp .* max(repXiMin + Frep .* ...
    (prevR - repXiMin), repXiMin);

Rcomp = R > repXiMax;
R = ~Rcomp .* R + Rcomp .* min(repXiMax - Frep .* ...
    (repXiMax - prevR), repXiMax);

end

